@@ -10,6 +10,7 @@ use MIME::Base64;
 use POSIX qw(strftime);
 use Lemonldap::NG::Common::FormEncode;
 use Lemonldap::NG::Portal::Main::Constants qw(
+  PE_OK
   PE_BADCREDENTIALS
   PE_BADMAILTOKEN
   PE_CAPTCHAEMPTY
@@ -23,10 +24,6 @@ use Lemonldap::NG::Portal::Main::Constants qw(
   PE_MAILOK
   PE_MALFORMEDUSER
   PE_NOTOKEN
-  PE_OK
-  PE_PASSWORDFIRSTACCESS
-  PE_PASSWORDFORMEMPTY
-  PE_PASSWORD_OK
   PE_TOKENEXPIRED
   PE_USERNOTFOUND
   PE_RESETCERTIFICATE_INVALID
@@ -34,10 +31,13 @@ use Lemonldap::NG::Portal::Main::Constants qw(
   PE_RESETCERTIFICATE_FIRSTACCESS
 );
 
-our $VERSION = '2.1.0';
+our $VERSION = '2.0.8';
 
-extends 'Lemonldap::NG::Portal::Main::Plugin',
-  'Lemonldap::NG::Portal::Lib::SMTP', 'Lemonldap::NG::Portal::Lib::_tokenRule';
+extends qw(
+  Lemonldap::NG::Portal::Main::Plugin
+  Lemonldap::NG::Portal::Lib::SMTP
+  Lemonldap::NG::Portal::Lib::_tokenRule
+);
 
 # PROPERTIES
 
@@ -107,6 +107,7 @@ sub init {
             '::CertificateResetByMail::' . $self->conf->{registerDB}
         )
     ) or return 0;
+
     return 1;
 }
 
@@ -261,8 +262,7 @@ sub _certificateReset {
     my $mailSession = $self->getCertificateSession( $req->{user} );
     unless ( $mailSession or $mailToken ) {
 
-        # Create a new session
-
+        ## Create a new session
         my $infos = {};
 
         # Set _utime for session autoremove
@@ -376,8 +376,9 @@ sub _certificateReset {
         else {
 
             # Use HTML template
-            $body = $self->loadTemplate(
-                'mail_confirm',
+            $body = $self->loadMailTemplate(
+                $req,
+                'mail_certificateConfirm',
                 filter => $tr,
                 params => \%tplPrms
             );
@@ -392,8 +393,9 @@ sub _certificateReset {
 
         # Send mail
         unless (
-            $self->sendmail(
-                $req->data->{mailAddress}, $subject, $body, $html
+            $self->send_mail(
+                $req->data->{mailAddress},
+                $subject, $body, $html
             )
           )
         {
@@ -423,7 +425,7 @@ sub modifyCertificate {
     my $x509;
     my $notAfter;
 
-    $self->logger->debug('Change your Certificate form response');
+    $self->logger->debug('Change your certificate form response');
 
     if ( my $token = $req->param('token') ) {
         $req->sessionInfo( $self->ott->getToken($token) );
@@ -451,10 +453,9 @@ sub modifyCertificate {
 
     #Updload certificate
     my $upload = $req->uploads->{certif};
-    unless ( $upload->size > 0 ) { return PE_RESETCERTIFICATE_FORMEMPTY; }
-
-    # Get Certificate
+    return PE_RESETCERTIFICATE_FORMEMPTY unless ( $upload->size > 0 );
 
+    # Get certificate
     my $file = $upload->path;
     $self->userLogger->debug( "Temporaly file " . $file );
 
@@ -472,11 +473,9 @@ sub modifyCertificate {
     unless ($x509) {
         $self->userLogger->debug( "Unable to decode certificate for user  "
               . Net::SSLeay::ERR_error_string( Net::SSLeay::ERR_get_error() ) );
-
-        #return PE_CERTIFICATE_INVALID;
         return PE_RESETCERTIFICATE_INVALID;
     }
-    $self->userLogger->debug("Certificate decoded successfully");
+    $self->userLogger->debug("Certificate successfully decoded");
     $notAfter = Net::SSLeay::P_ASN1_TIME_get_isotime(
         Net::SSLeay::X509_get_notAfter($x509) );
 
@@ -487,25 +486,22 @@ sub modifyCertificate {
         Net::SSLeay::X509_get_serialNumber($x509) );
 
     $self->userLogger->debug(
-"Certificate will expire after $notAfter, Issuer  $x509issuer and serialNumber $x509serial"
+"Certificate will expire after $notAfter, Issuer $x509issuer and serialNumber $x509serial"
     );
 
-    # Check Certificate Validity before store
+    # Check certificate validity before store
     if (
         $self->checkCertificateValidity( $notAfter,
             $self->conf->{certificateResetByMailValidityDelay} ) == 0
       )
     {
         $self->userLogger->debug(
-"Your cettificate is no longer valid in $self->conf->{certificateValidityDelay}"
+"Your certificate is no longer valid in $self->conf->{certificateValidityDelay}"
         );
         return PE_RESETCERTIFICATE_INVALID;
-
-        #return PE_PASSWORD_MISMATCH;
     }
 
     # Build serial number hex: example f3:08:52:63:28:29:fa:e2
-
     my @numberstring = split //, lc($x509serial);
     my $serial       = "";
     for ( my $i = 0 ; $i <= $#numberstring ; $i += 2 ) {
@@ -514,7 +510,6 @@ sub modifyCertificate {
     }
 
 # format issuer in the good format example "CN=CA,OU=CISIRH,O=MINEFI,L=Paris,ST=France,C=FR"
-
     my @issuertab = split /\//, $x509issuer;
     shift(@issuertab);
     my $issuer = join( ",", reverse(@issuertab) );
@@ -528,18 +523,17 @@ sub modifyCertificate {
     # Get attribut userCertificate;binary  value
     my $cert = $self->certificateHash($file);
 
-    # modif the ldap certificate attribute
+    # Modify ldap certificate attribute
     $req->user( $req->{sessionInfo}->{_user} );
     my $result =
-      $self->registerModule->modifCertificate( $certificatExactAssertion,
-        $cert, $req );
+      $self->registerModule->modifCertificate( $req, $certificatExactAssertion,
+        $cert );
     $self->{user} = undef;
 
     # Mail token can be used only one time, delete the session if all is ok
-    #
     return $result unless ( $result == PE_OK );
 
-    # Send mail to notify the certificate reset sucessfully
+    # Send mail to notify the certificate has been successfully reset
     $req->data->{mailAddress} ||=
       $self->p->getFirstValue(
         $req->{sessionInfo}->{ $self->conf->{mailSessionKey} } );
@@ -562,8 +556,9 @@ sub modifyCertificate {
     else {
 
         # Use HTML template
-        $body = $self->loadTemplate(
-            'mail_certificatReset',
+        $body = $self->loadMailTemplate(
+            $req,
+            'mail_certificateReset',
             filter => $tr,
             params => \%tplPrms
         );
@@ -575,7 +570,7 @@ sub modifyCertificate {
 
     # Send mail
     return PE_MAILERROR
-      unless $self->sendmail( $req->data->{mailAddress}, $subject, $body,
+      unless $self->send_mail( $req->data->{mailAddress}, $subject, $body,
         $html );
 
     return PE_MAILOK;
@@ -627,7 +622,7 @@ sub display {
         $tplPrm{MAIL_TOKEN} = $req->data->{mailToken};
     }
 
-    # Display captcha if it's enabled
+    # Display captcha if enabled
     if ( $req->captcha ) {
         $tplPrm{CAPTCHA_SRC}  = $req->captcha;
         $tplPrm{CAPTCHA_SIZE} = $self->conf->{captcha_size};
@@ -669,7 +664,7 @@ sub display {
         $tplPrm{DISPLAY_MAILSENT} = 1;
     }
 
-    # Display Certificate Reset form
+    # Display certificate reset form
     elsif ( $req->data->{mailToken}
         and $req->error != PE_MAILERROR
         and $req->error != PE_BADMAILTOKEN
@@ -679,7 +674,7 @@ sub display {
         $tplPrm{DISPLAY_CERTIF_FORM} = 1;
     }
 
-    # Display Certificate Reset form again if certificate invalid
+    # Display certificate reset form again if certificate invalid
     elsif ($req->error == PE_RESETCERTIFICATE_FORMEMPTY
         || $req->error == PE_RESETCERTIFICATE_INVALID )
     {
@@ -690,13 +685,12 @@ sub display {
     return 'certificateReset', \%tplPrm;
 }
 
-#tring getCertifResetSession (string mail)
+#string getCertifResetSession (string mail)
 # Check if a certificate reset session exists
 # @param mail the value of the mail key in session
 # @return the first session id found or nothing if no session
 sub getCertificateSession {
     my ( $self, $user ) = @_;
-
     my $moduleOptions = $self->conf->{globalStorageOptions} || {};
     $moduleOptions->{backend} = $self->conf->{globalStorage};
     my $module = "Lemonldap::NG::Common::Apache::Session";
@@ -718,26 +712,11 @@ sub getCertificateSession {
     return "";
 }
 
-# Use Certificate Update parameter to send mail
-
-sub sendmail {
-
-    my ( $self, $mail, $subject, $body, $html ) = @_;
-
-    $self->{mailFrom}    = $self->conf->{certificateResetByMailSender};
-    $self->{mailReplyTo} = $self->conf->{certificateResetByMailReplyTo};
-
-    return $self->send_mail( $mail, $subject, $body, $html );
-}
-
 sub checkCertificateValidity {
-
     my ( $self, $notAfter, $delay ) = @_;
     my $dtNow;    # now in format DateTime
     my $days;     # difference between NotAfter and now
-
-    my $f = DateTime::Format::RFC3339->new();
-
+    my $f          = DateTime::Format::RFC3339->new();
     my $dtNotAfter = $f->parse_datetime($notAfter);
     $self->userLogger->debug("Not After Date: $dtNotAfter");
 
@@ -761,7 +740,6 @@ sub checkCertificateValidity {
 }
 
 sub certificateHash {
-
     my ( $self, $file ) = @_;
     my $cert;
 
